pub struct Capability {
pub add_capabilities: Vec<String>,
pub drop_capabilities: Vec<String>,
pub add_ambient_capabilities: Vec<String>,
}Expand description
Capability contains the container capabilities to add or drop Dropping a capability will drop it from all sets. If a capability is added to only the add_capabilities list then it gets added to permitted, inheritable, effective and bounding sets, i.e. all sets except the ambient set. If a capability is added to only the add_ambient_capabilities list then it gets added to all sets, i.e permitted inheritable, effective, bounding and ambient sets. If a capability is added to add_capabilities and add_ambient_capabilities lists then it gets added to all sets, i.e. permitted, inheritable, effective, bounding and ambient sets.
Fields
add_capabilities: Vec<String>List of capabilities to add.
drop_capabilities: Vec<String>List of capabilities to drop.
add_ambient_capabilities: Vec<String>List of ambient capabilities to add.