Container

Struct Container 

pub struct Container {
    pub id: String,
    pub pod_sandbox_id: String,
    pub metadata: Option<ContainerMetadata>,
    pub image: Option<ImageSpec>,
    pub image_ref: String,
    pub state: i32,
    pub created_at: i64,
    pub labels: HashMap<String, String>,
    pub annotations: HashMap<String, String>,
    pub image_id: String,
}
Container provides the runtime information for a container, such as ID, hash, state of the container.

Fields

id: String

ID of the container, used by the container runtime to identify a container.

pod_sandbox_id: String

ID of the sandbox to which this container belongs.

metadata: Option<ContainerMetadata>

Metadata of the container.

image: Option<ImageSpec>

Spec of the image.

image_ref: String

Digested reference to the image in use.

state: i32

State of the container.

created_at: i64

Creation time of the container in nanoseconds.

labels: HashMap<String, String>

Key-value pairs that may be used to scope and select individual resources.

annotations: HashMap<String, String>

Unstructured key-value map holding arbitrary metadata. Annotations MUST NOT be altered by the runtime; the value of this field MUST be identical to that of the corresponding ContainerConfig used to instantiate this Container.

image_id: String

Reference to the unique identifier of the image, on the node, as returned in the image service apis.

Note: The image_ref above has been historically used by container runtimes to reference images by digest. The image_ref has been also used in the kubelet image garbage collection, which does not work with digests at all. To separate and avoid possible misusage, we now introduce the image_id field, which should always refer to a unique image identifier on the node.

Implementations

Source

impl Container

pub fn state(&self) -> ContainerState

Returns the enum value of state, or the default if the field is set to an invalid enum value.

pub fn set_state(&mut self, value: ContainerState)

Sets state to the provided enum value.