pub struct ContainerAttributes {
pub id: String,
pub metadata: Option<ContainerMetadata>,
pub labels: HashMap<String, String>,
pub annotations: HashMap<String, String>,
}Expand description
ContainerAttributes provides basic information of the container.
Fields
id: StringID of the container.
metadata: Option<ContainerMetadata>Metadata of the container.
labels: HashMap<String, String>Key-value pairs that may be used to scope and select individual resources.
annotations: HashMap<String, String>Unstructured key-value map holding arbitrary metadata. Annotations MUST NOT be altered by the runtime; the value of this field MUST be identical to that of the corresponding ContainerConfig used to instantiate the Container this status represents.