ContainerStatus

Struct ContainerStatus 

pub struct ContainerStatus {
Show 18 fields pub id: String, pub metadata: Option<ContainerMetadata>, pub state: i32, pub created_at: i64, pub started_at: i64, pub finished_at: i64, pub exit_code: i32, pub image: Option<ImageSpec>, pub image_ref: String, pub reason: String, pub message: String, pub labels: HashMap<String, String>, pub annotations: HashMap<String, String>, pub mounts: Vec<Mount>, pub log_path: String, pub resources: Option<ContainerResources>, pub image_id: String, pub user: Option<ContainerUser>,
}
ContainerStatus represents the status of a container.

Fields

id: String

ID of the container.

metadata: Option<ContainerMetadata>

Metadata of the container.

state: i32

Status of the container.

created_at: i64

Creation time of the container in nanoseconds.

started_at: i64

Start time of the container in nanoseconds. Default: 0 (not specified).

finished_at: i64

Finish time of the container in nanoseconds. Default: 0 (not specified).

exit_code: i32

Exit code of the container. Only required when finished_at != 0. Default: 0.

image: Option<ImageSpec>

Spec of the image.

image_ref: String

Digested reference to the image in use.

reason: String

Brief CamelCase string explaining why container is in its current state. Must be set to “OOMKilled” for containers terminated by cgroup-based Out-of-Memory killer.

message: String

Human-readable message indicating details about why container is in its current state.

labels: HashMap<String, String>

Key-value pairs that may be used to scope and select individual resources.

annotations: HashMap<String, String>

Unstructured key-value map holding arbitrary metadata. Annotations MUST NOT be altered by the runtime; the value of this field MUST be identical to that of the corresponding ContainerConfig used to instantiate the Container this status represents.

mounts: Vec<Mount>

Mounts for the container.

log_path: String

Log path of container.

resources: Option<ContainerResources>

Resource limits configuration of the container.

image_id: String

Reference to the unique identifier of the image, on the node, as returned in the image service apis.

Note: The image_ref above has been historically used by container runtimes to reference images by digest. To separate and avoid possible misusage, we now introduce the image_id field, which should always refer to a unique image identifier on the node.

user: Option<ContainerUser>

User identities initially attached to the container

Implementations

Source

impl ContainerStatus

pub fn state(&self) -> ContainerState

Returns the enum value of state, or the default if the field is set to an invalid enum value.

pub fn set_state(&mut self, value: ContainerState)

Sets state to the provided enum value.