pub struct ExecSyncResponse {
pub stdout: Vec<u8>,
pub stderr: Vec<u8>,
pub exit_code: i32,
}Fields
stdout: Vec<u8>Captured command stdout output. The runtime should cap the output of this response to 16MB. If the stdout of the command produces more than 16MB, the remaining output should be discarded, and the command should proceed with no error. See CVE-2022-1708 and CVE-2022-31030 for more information.
stderr: Vec<u8>Captured command stderr output. The runtime should cap the output of this response to 16MB. If the stderr of the command produces more than 16MB, the remaining output should be discarded, and the command should proceed with no error. See CVE-2022-1708 and CVE-2022-31030 for more information.
exit_code: i32Exit code the command finished with. Default: 0 (success).