pub struct LinuxPodSandboxConfig {
pub cgroup_parent: String,
pub security_context: Option<LinuxSandboxSecurityContext>,
pub sysctls: HashMap<String, String>,
pub overhead: Option<LinuxContainerResources>,
pub resources: Option<LinuxContainerResources>,
}Expand description
LinuxPodSandboxConfig holds platform-specific configurations for Linux host platforms and Linux-based containers.
Fields
cgroup_parent: StringParent cgroup of the PodSandbox. The cgroupfs style syntax will be used, but the container runtime can convert it to systemd semantics if needed.
security_context: Option<LinuxSandboxSecurityContext>LinuxSandboxSecurityContext holds sandbox security attributes.
sysctls: HashMap<String, String>Sysctls holds linux sysctls config for the sandbox.
overhead: Option<LinuxContainerResources>Optional overhead represents the overheads associated with this sandbox
resources: Option<LinuxContainerResources>Optional resources represents the sum of container resources for this sandbox