pub struct LinuxSandboxSecurityContext {
pub namespace_options: Option<NamespaceOption>,
pub selinux_options: Option<SeLinuxOption>,
pub run_as_user: Option<Int64Value>,
pub run_as_group: Option<Int64Value>,
pub readonly_rootfs: bool,
pub supplemental_groups: Vec<i64>,
pub supplemental_groups_policy: i32,
pub privileged: bool,
pub seccomp: Option<SecurityProfile>,
pub apparmor: Option<SecurityProfile>,
pub seccomp_profile_path: String,
}Expand description
LinuxSandboxSecurityContext holds linux security configuration that will be applied to a sandbox. Note that:
- It does not apply to containers in the pods.
- It may not be applicable to a PodSandbox which does not contain any running process.
Fields
namespace_options: Option<NamespaceOption>Configurations for the sandbox’s namespaces. This will be used only if the PodSandbox uses namespace for isolation.
selinux_options: Option<SeLinuxOption>Optional SELinux context to be applied.
run_as_user: Option<Int64Value>UID to run sandbox processes as, when applicable.
run_as_group: Option<Int64Value>GID to run sandbox processes as, when applicable. run_as_group should only be specified when run_as_user is specified; otherwise, the runtime MUST error.
readonly_rootfs: boolIf set, the root filesystem of the sandbox is read-only.
supplemental_groups: Vec<i64>List of groups applied to the first process run in each container. supplemental_groups_policy can control how groups will be calculated.
supplemental_groups_policy: i32supplemental_groups_policy defines how supplemental groups of the first container processes are calculated. Valid values are “Merge” and “Strict”. If not specified, “Merge” is used.
privileged: boolIndicates whether the sandbox will be asked to run a privileged container. If a privileged container is to be executed within it, this MUST be true. This allows a sandbox to take additional security precautions if no privileged containers are expected to be run.
seccomp: Option<SecurityProfile>Seccomp profile for the sandbox.
apparmor: Option<SecurityProfile>AppArmor profile for the sandbox.
seccomp_profile_path: StringSeccomp profile for the sandbox, candidate values are:
- runtime/default: the default profile for the container runtime
- unconfined: unconfined profile, ie, no seccomp sandboxing
- localhost/
: the profile installed on the node. is the full path of the profile. Default: “”, which is identical with unconfined.
Implementations
Sourceimpl LinuxSandboxSecurityContext
impl LinuxSandboxSecurityContext
Sourcepub fn supplemental_groups_policy(&self) -> SupplementalGroupsPolicy
pub fn supplemental_groups_policy(&self) -> SupplementalGroupsPolicy
Returns the enum value of supplemental_groups_policy, or the default if the field is set to an invalid enum value.
Sourcepub fn set_supplemental_groups_policy(
&mut self,
value: SupplementalGroupsPolicy,
)
pub fn set_supplemental_groups_policy( &mut self, value: SupplementalGroupsPolicy, )
Sets supplemental_groups_policy to the provided enum value.