pub struct MetricDescriptor {
pub name: String,
pub help: String,
pub label_keys: Vec<String>,
}Fields
name: StringThe name field will be used as a unique identifier of this MetricDescriptor, and be used in conjunction with the Metric structure to populate the full Metric.
help: Stringlabel_keys: Vec<String>When a metric uses this metric descriptor, it should only define labels that have previously been declared in label_keys. It is the responsibility of the runtime to correctly keep sorted the keys and values. If the two slices have different length, the behavior is undefined.