pub struct NetworkUsage {
pub timestamp: i64,
pub default_interface: Option<NetworkInterfaceUsage>,
pub interfaces: Vec<NetworkInterfaceUsage>,
}Expand description
NetworkUsage contains data about network resources.
Fields
timestamp: i64Timestamp in nanoseconds at which the information were collected. Must be > 0.
default_interface: Option<NetworkInterfaceUsage>Stats for the default network interface.
interfaces: Vec<NetworkInterfaceUsage>Stats for all found network interfaces, excluding the default.