pub struct PodSandbox {
pub id: String,
pub metadata: Option<PodSandboxMetadata>,
pub state: i32,
pub created_at: i64,
pub labels: HashMap<String, String>,
pub annotations: HashMap<String, String>,
pub runtime_handler: String,
}Expand description
PodSandbox contains minimal information about a sandbox.
Fields
id: StringID of the PodSandbox.
metadata: Option<PodSandboxMetadata>Metadata of the PodSandbox.
state: i32State of the PodSandbox.
created_at: i64Creation timestamps of the PodSandbox in nanoseconds. Must be > 0.
labels: HashMap<String, String>Labels of the PodSandbox.
annotations: HashMap<String, String>Unstructured key-value map holding arbitrary metadata. Annotations MUST NOT be altered by the runtime; the value of this field MUST be identical to that of the corresponding PodSandboxConfig used to instantiate this PodSandbox.
runtime_handler: Stringruntime configuration used for this PodSandbox.
Implementations
Sourceimpl PodSandbox
impl PodSandbox
Sourcepub fn state(&self) -> PodSandboxState
pub fn state(&self) -> PodSandboxState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: PodSandboxState)
pub fn set_state(&mut self, value: PodSandboxState)
Sets state to the provided enum value.