pub struct PodSandboxAttributes {
pub id: String,
pub metadata: Option<PodSandboxMetadata>,
pub labels: HashMap<String, String>,
pub annotations: HashMap<String, String>,
}Expand description
PodSandboxAttributes provides basic information of the pod sandbox.
Fields
id: StringID of the pod sandbox.
metadata: Option<PodSandboxMetadata>Metadata of the pod sandbox.
labels: HashMap<String, String>Key-value pairs that may be used to scope and select individual resources.
annotations: HashMap<String, String>Unstructured key-value map holding arbitrary metadata. Annotations MUST NOT be altered by the runtime; the value of this field MUST be identical to that of the corresponding PodSandboxStatus used to instantiate the PodSandbox this status represents.