PodSandboxConfig

Struct PodSandboxConfig 

pub struct PodSandboxConfig {
    pub metadata: Option<PodSandboxMetadata>,
    pub hostname: String,
    pub log_directory: String,
    pub dns_config: Option<DnsConfig>,
    pub port_mappings: Vec<PortMapping>,
    pub labels: HashMap<String, String>,
    pub annotations: HashMap<String, String>,
    pub linux: Option<LinuxPodSandboxConfig>,
    pub windows: Option<WindowsPodSandboxConfig>,
}
PodSandboxConfig holds all the required and optional fields for creating a sandbox.

Fields

metadata: Option<PodSandboxMetadata>

Metadata of the sandbox. This information will uniquely identify the sandbox, and the runtime should leverage this to ensure correct operation. The runtime may also use this information to improve UX, such as by constructing a readable name.

hostname: String

Hostname of the sandbox. Hostname could only be empty when the pod network namespace is NODE.

log_directory: String

Path to the directory on the host in which container log files are stored. By default the log of a container going into the LogDirectory will be hooked up to STDOUT and STDERR. However, the LogDirectory may contain binary log files with structured logging data from the individual containers. For example, the files might be newline separated JSON structured logs, systemd-journald journal files, gRPC trace files, etc. E.g., PodSandboxConfig.LogDirectory = /var/log/pods/<NAMESPACE>_<NAME>_<UID>/ ContainerConfig.LogPath = containerName/Instance#.log

dns_config: Option<DnsConfig>

DNS config for the sandbox.

port_mappings: Vec<PortMapping>

Port mappings for the sandbox.

labels: HashMap<String, String>

Key-value pairs that may be used to scope and select individual resources.

annotations: HashMap<String, String>

Unstructured key-value map that may be set by the kubelet to store and retrieve arbitrary metadata. This will include any annotations set on a pod through the Kubernetes API.

Annotations MUST NOT be altered by the runtime; the annotations stored here MUST be returned in the PodSandboxStatus associated with the pod this PodSandboxConfig creates.

In general, in order to preserve a well-defined interface between the kubelet and the container runtime, annotations SHOULD NOT influence runtime behaviour.

Annotations can also be useful for runtime authors to experiment with new features that are opaque to the Kubernetes APIs (both user-facing and the CRI). Whenever possible, however, runtime authors SHOULD consider proposing new typed fields for any new features instead.

linux: Option<LinuxPodSandboxConfig>

Optional configurations specific to Linux hosts.

windows: Option<WindowsPodSandboxConfig>

Optional configurations specific to Windows hosts.