pub struct PodSandboxStatus {
pub id: String,
pub metadata: Option<PodSandboxMetadata>,
pub state: i32,
pub created_at: i64,
pub network: Option<PodSandboxNetworkStatus>,
pub linux: Option<LinuxPodSandboxStatus>,
pub labels: HashMap<String, String>,
pub annotations: HashMap<String, String>,
pub runtime_handler: String,
}Expand description
PodSandboxStatus contains the status of the PodSandbox.
Fields
id: StringID of the sandbox.
metadata: Option<PodSandboxMetadata>Metadata of the sandbox.
state: i32State of the sandbox.
created_at: i64Creation timestamp of the sandbox in nanoseconds. Must be > 0.
network: Option<PodSandboxNetworkStatus>Network contains network status if network is handled by the runtime.
linux: Option<LinuxPodSandboxStatus>Linux-specific status to a pod sandbox.
labels: HashMap<String, String>Labels are key-value pairs that may be used to scope and select individual resources.
annotations: HashMap<String, String>Unstructured key-value map holding arbitrary metadata. Annotations MUST NOT be altered by the runtime; the value of this field MUST be identical to that of the corresponding PodSandboxConfig used to instantiate the pod sandbox this status represents.
runtime_handler: Stringruntime configuration used for this PodSandbox.
Implementations
Sourceimpl PodSandboxStatus
impl PodSandboxStatus
Sourcepub fn state(&self) -> PodSandboxState
pub fn state(&self) -> PodSandboxState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: PodSandboxState)
pub fn set_state(&mut self, value: PodSandboxState)
Sets state to the provided enum value.