pub struct RuntimeCondition {
pub type: String,
pub status: bool,
pub reason: String,
pub message: String,
}Expand description
RuntimeCondition contains condition information for the runtime. There are 2 kinds of runtime conditions:
- Required conditions: Conditions are required for kubelet to work
properly. If any required condition is unmet, the node will be not ready.
The required conditions include:
- RuntimeReady: RuntimeReady means the runtime is up and ready to accept basic containers e.g. container only needs host network.
- NetworkReady: NetworkReady means the runtime network is up and ready to accept containers which require container network.
- Optional conditions: Conditions are informative to the user, but kubelet will not rely on. Since condition type is an arbitrary string, all conditions not required are optional. These conditions will be exposed to users to help them understand the status of the system.
Fields
type: StringType of runtime condition.
status: boolStatus of the condition, one of true/false. Default: false.
reason: StringBrief CamelCase string containing reason for the condition’s last transition.
message: StringHuman-readable message indicating details about last transition.