pub struct RuntimeFeatures {
pub supplemental_groups_policy: bool,
}Expand description
RuntimeFeatures describes the set of features implemented by the CRI implementation. The features contained in the RuntimeFeatures should depend only on the cri implementation independent of runtime handlers.
Fields
supplemental_groups_policy: boolsupplemental_groups_policy is set to true if the runtime supports SupplementalGroupsPolicy and ContainerUser.