pub struct RuntimeHandlerFeatures {
pub recursive_read_only_mounts: bool,
pub user_namespaces: bool,
}Expand description
RuntimeHandlerFeatures is a set of features implemented by the runtime handler.
Fields
recursive_read_only_mounts: boolrecursive_read_only_mounts is set to true if the runtime handler supports
recursive read-only mounts.
For runc-compatible runtimes, availability of this feature can be detected by checking whether
the Linux kernel version is >= 5.12, and, runc features | jq .mountOptions contains “rro”.
user_namespaces: booluser_namespaces is set to true if the runtime handler supports user namespaces as implemented in Kubernetes. This means support for both, user namespaces and idmap mounts.