pub struct SecurityProfile {
pub profile_type: i32,
pub localhost_ref: String,
}Expand description
A security profile which can be used for sandboxes and containers.
Fields
profile_type: i32Indicator which ProfileType should be applied.
localhost_ref: StringIndicates that a pre-defined profile on the node should be used.
Must only be set if ProfileType is Localhost.
For seccomp, it must be an absolute path to the seccomp profile.
For AppArmor, this field is the AppArmor <profile name>/
Implementations
Sourceimpl SecurityProfile
impl SecurityProfile
Sourcepub fn profile_type(&self) -> ProfileType
pub fn profile_type(&self) -> ProfileType
Returns the enum value of profile_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_profile_type(&mut self, value: ProfileType)
pub fn set_profile_type(&mut self, value: ProfileType)
Sets profile_type to the provided enum value.