pub struct WindowsProcessUsage {
pub timestamp: i64,
pub process_count: Option<UInt64Value>,
}Expand description
WindowsProcessUsage are stats pertaining to processes specific to Windows.
Fields
timestamp: i64Timestamp in nanoseconds at which the information were collected. Must be > 0.
process_count: Option<UInt64Value>Number of processes.