pub struct WindowsSandboxSecurityContext {
pub run_as_username: String,
pub credential_spec: String,
pub host_process: bool,
pub namespace_options: Option<WindowsNamespaceOption>,
}Expand description
WindowsSandboxSecurityContext holds platform-specific configurations that will be applied to a sandbox. These settings will only apply to the sandbox container.
Fields
run_as_username: StringUser name to run the container process as. If specified, the user MUST exist in the container image and be resolved there by the runtime; otherwise, the runtime MUST return error.
credential_spec: StringThe contents of the GMSA credential spec to use to run this container.
host_process: boolIndicates whether the container requested to run as a HostProcess container.
namespace_options: Option<WindowsNamespaceOption>Configuration for the sandbox’s namespaces