pub struct ContainerStateValue {
pub state: i32,
}Expand description
ContainerStateValue is the wrapper of ContainerState.
Fields
state: i32State of the container.
Implementations
Sourceimpl ContainerStateValue
impl ContainerStateValue
Sourcepub fn state(&self) -> ContainerState
pub fn state(&self) -> ContainerState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: ContainerState)
pub fn set_state(&mut self, value: ContainerState)
Sets state to the provided enum value.