pub struct Image {
pub id: String,
pub repo_tags: Vec<String>,
pub repo_digests: Vec<String>,
pub size: u64,
pub uid: Option<Int64Value>,
pub username: String,
pub spec: Option<ImageSpec>,
pub pinned: bool,
}Expand description
Basic information about a container image.
Fields
id: StringID of the image.
Other names by which this image is known.
repo_digests: Vec<String>Digests by which this image is known.
size: u64Size of the image in bytes. Must be > 0.
uid: Option<Int64Value>UID that will run the command(s). This is used as a default if no user is specified when creating the container. UID and the following user name are mutually exclusive.
username: StringUser name that will run the command(s). This is used if UID is not set and no user is specified when creating container.
spec: Option<ImageSpec>ImageSpec for image which includes annotations
pinned: boolRecommendation on whether this image should be exempt from garbage collection. It must only be treated as a recommendation – the client can still request that the image be deleted, and the runtime must oblige.