pub struct ImageSpec {
pub image: String,
pub annotations: HashMap<String, String>,
pub user_specified_image: String,
pub runtime_handler: String,
}Expand description
ImageSpec is an internal representation of an image.
Fields
image: StringContainer’s Image field (e.g. imageID or imageDigest).
annotations: HashMap<String, String>Unstructured key-value map holding arbitrary metadata. ImageSpec Annotations can be used to help the runtime target specific images in multi-arch images.
user_specified_image: StringThe container image reference specified by the user (e.g. image[:tag] or digest). Only set if available within the RPC context.
runtime_handler: StringRuntime handler to use for pulling the image. If the runtime handler is unknown, the request should be rejected. An empty string would select the default runtime handler.