pub struct ImageStatusResponse {
pub image: Option<Image>,
pub info: HashMap<String, String>,
}Fields
image: Option<Image>Status of the image.
info: HashMap<String, String>Info is extra information of the Image. The key could be arbitrary string, and value should be in json format. The information could include anything useful for debug, e.g. image config for oci image based container runtime. It should only be returned non-empty when Verbose is true.