pub struct LinuxRuntimeConfiguration {
pub cgroup_driver: i32,
}Fields
cgroup_driver: i32Cgroup driver to use Note: this field should not change for the lifecycle of the Kubelet, or while there are running containers. The Kubelet will not re-request this after startup, and will construct the cgroup hierarchy assuming it is static. If the runtime wishes to change this value, it must be accompanied by removal of all pods, and a restart of the Kubelet. The easiest way to do this is with a full node reboot.
Implementations
Sourceimpl LinuxRuntimeConfiguration
impl LinuxRuntimeConfiguration
Sourcepub fn cgroup_driver(&self) -> CgroupDriver
pub fn cgroup_driver(&self) -> CgroupDriver
Returns the enum value of cgroup_driver, or the default if the field is set to an invalid enum value.
Sourcepub fn set_cgroup_driver(&mut self, value: CgroupDriver)
pub fn set_cgroup_driver(&mut self, value: CgroupDriver)
Sets cgroup_driver to the provided enum value.