pub struct MemoryUsage {
pub timestamp: i64,
pub working_set_bytes: Option<UInt64Value>,
pub available_bytes: Option<UInt64Value>,
pub usage_bytes: Option<UInt64Value>,
pub rss_bytes: Option<UInt64Value>,
pub page_faults: Option<UInt64Value>,
pub major_page_faults: Option<UInt64Value>,
}Expand description
MemoryUsage provides the memory usage information.
Fields
timestamp: i64Timestamp in nanoseconds at which the information were collected. Must be > 0.
working_set_bytes: Option<UInt64Value>The amount of working set memory in bytes.
available_bytes: Option<UInt64Value>Available memory for use. This is defined as the memory limit - workingSetBytes.
usage_bytes: Option<UInt64Value>Total memory in use. This includes all memory regardless of when it was accessed.
rss_bytes: Option<UInt64Value>The amount of anonymous and swap cache memory (includes transparent hugepages).
page_faults: Option<UInt64Value>Cumulative number of minor page faults.
major_page_faults: Option<UInt64Value>Cumulative number of major page faults.