pub struct Mount {
pub container_path: String,
pub host_path: String,
pub readonly: bool,
pub selinux_relabel: bool,
pub propagation: i32,
pub uid_mappings: Vec<IdMapping>,
pub gid_mappings: Vec<IdMapping>,
pub recursive_read_only: bool,
pub image: Option<ImageSpec>,
}Expand description
Mount specifies a host volume to mount into a container.
Fields
container_path: StringPath of the mount within the container.
host_path: StringPath of the mount on the host. Has to be empty if the image field below is provided, because those fields are mutually exclusive. If the image field below is nil and the host path doesn’t exist, then runtimes should report an error. If the hostpath is a symbolic link, runtimes should follow the symlink and mount the real destination to container.
readonly: boolIf set, the mount is read-only.
selinux_relabel: boolIf set, the mount needs SELinux relabeling.
propagation: i32Requested propagation mode.
uid_mappings: Vec<IdMapping>UidMappings specifies the runtime UID mappings for the mount.
gid_mappings: Vec<IdMapping>GidMappings specifies the runtime GID mappings for the mount.
recursive_read_only: boolIf set to true, the mount is made recursive read-only. In this CRI API, recursive_read_only is a plain true/false boolean, although its equivalent in the Kubernetes core API is a quaternary that can be nil, “Enabled”, “IfPossible”, or “Disabled”. kubelet translates that quaternary value in the core API into a boolean in this CRI API. Remarks:
- nil is just treated as false
- when set to true, readonly must be explicitly set to true, and propagation must be PRIVATE (0).
- (readonly == false && recursive_read_only == false) does not make the mount read-only.
image: Option<ImageSpec>Mount an image reference (image ID, with or without digest), which is a special use case for image volume mounts. If this field is set, then host_path should be unset. All OCI mounts are per feature definition readonly. The kubelet does an PullImage RPC and evaluates the returned PullImageResponse.image_ref value, which is then set to the ImageSpec.image field. Runtimes are expected to mount the image as required. Introduced in the OCI Volume Source KEP: https://kep.k8s.io/4639
Implementations
Sourceimpl Mount
impl Mount
Sourcepub fn propagation(&self) -> MountPropagation
pub fn propagation(&self) -> MountPropagation
Returns the enum value of propagation, or the default if the field is set to an invalid enum value.
Sourcepub fn set_propagation(&mut self, value: MountPropagation)
pub fn set_propagation(&mut self, value: MountPropagation)
Sets propagation to the provided enum value.