pub struct Status {
pub code: i32,
pub message: String,
pub details: Vec<Any>,
}Fields
code: i32The status code, which should be an enum value of Code.
message: StringA developer-facing error message, which should be in English. Any
user-facing error message should be localized and sent in the
details field, or localized by the client.
details: Vec<Any>A list of messages that carry the error details. There is a common set of message types for APIs to use.
Implementations
Sourceimpl Status
impl Status
pub fn new(code: Code, message: impl Into<String>) -> Status
pub fn cancelled(message: impl Into<String>) -> Status
pub fn unknown(message: impl Into<String>) -> Status
pub fn invalid_argument(message: impl Into<String>) -> Status
pub fn deadline_exceeded(message: impl Into<String>) -> Status
pub fn not_found(message: impl Into<String>) -> Status
pub fn already_exists(message: impl Into<String>) -> Status
pub fn permission_denied(message: impl Into<String>) -> Status
pub fn unauthenticated(message: impl Into<String>) -> Status
pub fn resource_exhausted(message: impl Into<String>) -> Status
pub fn failed_precondition(message: impl Into<String>) -> Status
pub fn aborted(message: impl Into<String>) -> Status
pub fn out_of_range(message: impl Into<String>) -> Status
pub fn unimplemented(message: impl Into<String>) -> Status
pub fn internal(message: impl Into<String>) -> Status
pub fn data_loss(message: impl Into<String>) -> Status
pub fn from_error(err: impl Error) -> Status